==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDropdownGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownGroupDescription } from "./WebDropdownGroupDescription";
/**
 * @hidden
 */
var WebDropdownGroupDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownGroupDescriptionMetadata, _super);
    function WebDropdownGroupDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownGroupDescriptionMetadata.b = function (a) {
        if (WebDropdownGroupDescriptionMetadata.a == null) {
            WebDropdownGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownGroupDescriptionMetadata.c(WebDropdownGroupDescriptionMetadata.a);
        }
        if (a.j(WebDropdownGroupDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDropdownGroupDescriptionMetadata.a);
    };
    WebDropdownGroupDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownGroup");
        a.item("__tagNameWC", "String:igc-dropdown-group");
    };
    WebDropdownGroupDescriptionMetadata.d = function (a) {
        WebDropdownGroupDescriptionMetadata.b(a);
        a.aa("WebDropdownGroup", function () { return new WebDropdownGroupDescription(); });
        a.z("WebDropdownGroup", WebDropdownGroupDescriptionMetadata.a);
    };
    WebDropdownGroupDescriptionMetadata.$t = markType(WebDropdownGroupDescriptionMetadata, 'WebDropdownGroupDescriptionMetadata');
    WebDropdownGroupDescriptionMetadata.a = null;
    return WebDropdownGroupDescriptionMetadata;
}(Base));
export { WebDropdownGroupDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebDropdownGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownGroupDescription } from "./WebDropdownGroupDescription";
/**
 * @hidden
 */
var WebDropdownGroupDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownGroupDescriptionMetadata, _super);
    function WebDropdownGroupDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownGroupDescriptionMetadata.b = function (a) {
        if (WebDropdownGroupDescriptionMetadata.a == null) {
            WebDropdownGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownGroupDescriptionMetadata.c(WebDropdownGroupDescriptionMetadata.a);
        }
        if (a.k(WebDropdownGroupDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebDropdownGroupDescriptionMetadata.a);
    };
    WebDropdownGroupDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownGroup");
        a.item("__tagNameWC", "String:igc-dropdown-group");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebDropdownGroupDescriptionMetadata.d = function (a) {
        WebDropdownGroupDescriptionMetadata.b(a);
        a.ac("WebDropdownGroup", function () { return new WebDropdownGroupDescription(); });
        a.ab("WebDropdownGroup", WebDropdownGroupDescriptionMetadata.a);
    };
    WebDropdownGroupDescriptionMetadata.$t = markType(WebDropdownGroupDescriptionMetadata, 'WebDropdownGroupDescriptionMetadata');
    WebDropdownGroupDescriptionMetadata.a = null;
    return WebDropdownGroupDescriptionMetadata;
}(Base));
export { WebDropdownGroupDescriptionMetadata };
